@@ -2,8 +2,8 @@
 from .batch import ItemUpdate
 from .connection import DynamoDBConnection
 from .constants import (STRING, NUMBER, BINARY, STRING_SET, NUMBER_SET,
-                        BINARY_SET, NONE, TOTAL, INDEXES, ALL_OLD, UPDATED_OLD,
-                        ALL_NEW, UPDATED_NEW)
+                        BINARY_SET, LIST, BOOL, MAP, NULL, NONE, TOTAL,
+                        INDEXES, ALL_OLD, UPDATED_OLD, ALL_NEW, UPDATED_NEW)
 from .exception import (CheckFailed, ConditionalCheckFailedException,
                         ThroughputException,
                         ProvisionedThroughputExceededException, DynamoDBError)
@@ -11,4 +11,4 @@ from .fields import Throughput, Table, DynamoKey, LocalIndex, GlobalIndex
 from .types import Dynamizer, Binary, TYPES, TYPES_REV
 from .util import is_null
 
-__version__ = '0.2.2'
+__version__ = '0.3.0'
